@@ -2,7 +2,7 @@
 # Package       HiPi::Device::SPI
 # Description:  Wrapper for SPI communucation
 # Created       Fri Nov 23 13:55:49 2012
-# SVN Id        $Id: SPI.pm 1528 2013-03-18 06:06:42Z Mark Dootson $
+# SVN Id        $Id: SPI.pm 1604 2013-03-19 12:07:11Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -26,7 +26,7 @@ use HiPi;
 use HiPi::Utils qw( is_raspberry );
 use Try::Tiny;
 
-our $VERSION = '0.23';
+our $VERSION ='0.25';
 
 __PACKAGE__->create_accessors( qw ( fh fno delay speed bitsperword ) );
 
@@ -100,7 +100,7 @@ sub get_module_info {
 }
 
 sub get_bufsiz {
-    my $bufsiz = HiPi::qx_sudo_shell('cat /sys/module/spidev/parameters/bufsiz 2>&1');
+    my $bufsiz = HiPi::qx_sudo_shell('/bin/cat /sys/module/spidev/parameters/bufsiz 2>&1');
     if( $? ) {
         return $_moduleinfo[1]->{params}->{bufsiz};
     }
