@@ -2,7 +2,7 @@
 # Package       HiPi::Interface::MCP23017
 # Description:  Control MCP23017 Port Extender via I2C
 # Created       Sun Dec 02 01:42:27 2012
-# SVN Id        $Id: MCP23017.pm 1436 2013-03-17 03:04:15Z Mark Dootson $
+# SVN Id        $Id: MCP23017.pm 1521 2013-03-18 05:10:28Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -142,6 +142,7 @@ sub new {
         address     => 0x20,
         device      => undef,
         backend     => 'smbus',
+     _function_mode => 'hipi',
     );
     
     # get user params
@@ -155,6 +156,7 @@ sub new {
             $params{device} = HiPi::BCM2835::I2C->new(
                 address    => $params{address},
                 peripheral => ( $params{devicename} eq '/dev/i2c-0' ) ? HiPi::BCM2835::I2C::BB_I2C_PERI_0() : HiPi::BCM2835::I2C::BB_I2C_PERI_1(),
+            _function_mode => $params{_function_mode},
             );
         } else {
             require HiPi::Device::I2C;
